Skip to content
Open
Show file tree
Hide file tree
Changes from all commits
Commits
Show all changes
25 commits
Select commit Hold shift + click to select a range
243527b
Outputting into 3 diff folders
stloufra Aug 5, 2026
a35e32d
Start of prune
stloufra Aug 5, 2026
929654b
Put the process specific constants in the files
stloufra Aug 5, 2026
8d8c4af
Backend algos from CPPProcess to /backend
stloufra Aug 5, 2026
2c3fcfe
BugFix
stloufra Aug 5, 2026
b7a43d7
BugFix: gpu includes
stloufra Aug 5, 2026
8571c2e
Makefile and stray file deletion
stloufra Aug 5, 2026
a1eadfe
Redundant template file delete
stloufra Aug 5, 2026
050f49e
More generated code into template files
stloufra Aug 5, 2026
a72f55a
Delete f* files and copy acc. output mode
stloufra Aug 5, 2026
f552ba4
All color information in ColorData.h
stloufra Aug 5, 2026
a35d5f3
More prune
stloufra Aug 6, 2026
065d87a
Delete mgOn* from src
stloufra Aug 6, 2026
d557e72
Shrink CPPProcess
stloufra Aug 6, 2026
a919bcd
Uni namspace and bug fixed
stloufra Aug 17, 2026
f6b8c3c
createNormalizedColorMatrix noop for CPU
stloufra Aug 18, 2026
37990e3
hostChannel2iconfig only in runTest.cc
stloufra Aug 18, 2026
b8324d7
Clean the MGONGPU_CPPSIMD from /backend/cpu
stloufra Aug 18, 2026
a216429
Getting rid of the mgOnGpuVectors on cpu/gpu
stloufra Aug 18, 2026
c6c8140
Death code in mgOnGpuVectors on SIMD del
stloufra Aug 18, 2026
2c6c9ff
namespace madmatrix change
stloufra Aug 19, 2026
5e6989a
rambo/random move to /src/rambo in standalone
stloufra Aug 19, 2026
6b5a265
Comment bugfix
stloufra Aug 19, 2026
479494c
BugFix: relinking for before compiled backend
stloufra Aug 19, 2026
7ee6b19
HIP arch auto detect
stloufra Aug 20, 2026
File filter

Filter by extension

Filter by extension

Conversations
Failed to load comments.
Loading
Jump to
Jump to file
Failed to load files.
Loading
Diff view
Diff view
2 changes: 2 additions & 0 deletions .gitignore
Original file line number Diff line number Diff line change
Expand Up @@ -6,6 +6,8 @@ __pycache__
*.mod
*.a
PROC*
!madgraph/iolibs/template_files/madmatrix/ProcessData.h
!madgraph/iolibs/template_files/madmatrix/ProcessTables.h
cmd*
ptest*
*.pkl
Expand Down
633 changes: 0 additions & 633 deletions madgraph/iolibs/template_files/madmatrix/Bridge.h

This file was deleted.

164 changes: 0 additions & 164 deletions madgraph/iolibs/template_files/madmatrix/BridgeKernels.cc

This file was deleted.

146 changes: 0 additions & 146 deletions madgraph/iolibs/template_files/madmatrix/BridgeKernels.h

This file was deleted.

44 changes: 44 additions & 0 deletions madgraph/iolibs/template_files/madmatrix/ColorData.h
Original file line number Diff line number Diff line change
@@ -0,0 +1,44 @@
// Copyright (C) 2020-2026 CERN and UCLouvain.
// Licensed under the GNU Lesser General Public License (version 3 or later).
// Integrated with the MadGraph7 project in Feb 2026.
//
// Process-specific color structure, generated once per subprocess: the
// normalized color matrix (for color_sum_cpu/color_sum_gpu) and the
// diagram/channel/config maps for multichannel color selection.

#ifndef COLORDATA_H
#define COLORDATA_H 1

#include "mgOnGpuConfig.h"
#include "ProcessData.h"

namespace ColorMatrixData
{
constexpr int ncolor = ProcessData::ncolor;

%(color_matrix_lines)s
}

namespace mgOnGpu
{
// Diagram: C-indexed [0,ndiagrams). Channel (channelId): F-indexed [1,nchannels],
// not all diagrams have one (#919); channelId-1 indexes channel2iconfig. Config
// (iconfig): F-indexed [1,nconfigSDE]; iconfig-1 indexes icolamp.
constexpr unsigned int nchannels = %(nb_diag)i; // may be < ndiagrams, see #919
static_assert( nchannels <= ProcessData::ndiagrams, "nchannels should be <= ndiagrams" ); // #910 #919

// Map channel (C-indexed) to iconfig (F-indexed); -1 = no associated iconfig (#917)
__device__ constexpr int channel2iconfig[%(nb_diag)i] = {
%(channelc2iconfig_lines)s
};

// #configs with an associated iconfig for single-diagram enhancement (#917)
constexpr unsigned int nconfigSDE = %(nb_channel)s;

// Map iconfig (C-indexed) to the mask of allowed colors
__device__ constexpr bool icolamp[%(nb_channel)s][%(nb_color)s] = {
%(is_LC)s
};
}

#endif // COLORDATA_H
6 changes: 1 addition & 5 deletions madgraph/iolibs/template_files/madmatrix/MadgraphTest.h
Original file line number Diff line number Diff line change
Expand Up @@ -27,11 +27,7 @@
#include <string>
#include <vector>

#ifdef MGONGPUCPP_GPUIMPL
using mg5amcGpu::CPPProcess;
#else
using mg5amcCpu::CPPProcess;
#endif
using madmatrix::CPPProcess;

namespace
{
Expand Down
Loading
Loading